@@ -1,4 +1,4 @@
-#$Id: Agent.pm 427 2014-05-13 19:47:26Z maj $
+#$Id: Agent.pm 458 2014-07-01 03:42:52Z maj $
 use v5.10;
 package REST::Neo4p::Agent;
 use REST::Neo4p::Exceptions;
@@ -11,7 +11,7 @@ use warnings;
 our @ISA;
 our $VERSION;
 BEGIN {
-  $REST::Neo4p::Agent::VERSION = '0.2252';
+  $REST::Neo4p::Agent::VERSION = '0.2253';
 }
 
 our $AUTOLOAD;
@@ -22,7 +22,7 @@ our $RETRY_WAIT = 5;
 sub new {
   my $class = shift;
   my %args = @_;
-  my $mod = delete $args{agent_module};
+  my $mod = delete $args{agent_module} || 'LWP::UserAgent';
   die "No user agent module specified" unless $mod;
   $mod = join('::','REST::Neo4p::Agent',$mod);
   eval "require $mod;1" or REST::Neo4p::LocalException->throw("Module $mod is not available\n");
